==> nocc-1.9.5.txz: usr/local/www/nocc/lang/uk.php <==
<?php
/**
 * Language configuration file for NOCC
 *
 * Copyright 2001 Nicolas Chalanset <nicocha@free.fr>
 * Copyright 2001 Olivier Cahagne <cahagn_o@epita.fr>
 *
 * This file is part of NOCC. NOCC is free software under the terms of the
 * GNU General Public License. You should have received a copy of the license
 * along with NOCC.  If not, see <http://www.gnu.org/licenses/>.
 *
 * @package    NOCC
 * @subpackage Translations
 * @license    http://www.gnu.org/licenses/ GNU General Public License
 * @version    SVN: $Id: uk.php 2623 2014-10-06 10:07:46Z siebrand $
 */
/** Ukrainian (українська)
 * 
 * See the qqq 'language' for message documentation incl. usage of parameters
 * To improve a translation please visit http://translatewiki.net
 *
 * @ingroup Language
 * @file
 *
 * @author Andriykopanytsia
 * @author KEL
 * @author Prima klasy4na
 * @author Тест
 */

$lang_locale = 'uk_UA.UTF-8';
$lang_dir = 'ltr';
$default_date_format = '%d.%m.%Y';
$no_locale_date_format = '%d.%m.%Y';
$default_time_format = '%H:%M';
$err_user_empty = 'Не введений логін';
$err_passwd_empty = 'Не введений пароль';
$alt_delete = 'Видалити вибрані повідомлення';
$alt_delete_one = 'Видалити повідомлення';
$alt_new_msg = 'Нові повідомлення';
$alt_reply = 'Відповісти автору';
$alt_reply_all = 'Відповісти всім';
$alt_forward = 'Вперед';
$alt_next = 'Наступний';
$alt_prev = 'Назад';
$title_next_page = 'Наступна сторінка';
$title_prev_page = 'Попередня сторінка';
$title_next_msg = 'Наступне повідомлення';
$title_prev_msg = 'Попереднє повідомлення';
$html_theme_label = 'Тема:';
$html_welcome = 'Ласкаво просимо до %1$s';
$html_login = 'Увійти';
$html_user_label = 'Користувач:';
$html_passwd_label = 'Пароль:';
$html_submit = 'Надіслати';
$html_help = 'Довідка';
$html_server_label = 'Сервер:';
$html_wrong = 'Логін або пароль невірний';
$html_retry = 'Повторити';
$html_remember = 'Запам\'ятати налаштування';
$html_lang_label = 'Мова:';
$html_msgperpage_label = 'Повідомлень на сторінці:';
$html_preferences = 'Налаштування';
$html_full_name_label = 'Повне ім\'я:';
$html_email_address_label = 'Адреса електронної пошти';
$html_bccself = 'Копію собі';
$html_hide_addresses = 'Приховати адреси';
$html_outlook_quoting = 'Outlook стиль цитування';
$html_reply_to = 'Відповісти для';
$html_reply_to_label = 'Відповідь:';
$html_use_signature = 'Ставити підпис';
$html_signature = 'Підпис';
$html_signature_label = 'Підпис:';
$html_reply_leadin_label = 'Вступний блок відповіді:';
$html_prefs_updated = 'Налаштування оновлені';
$html_manage_folders_link = 'Керування теками IMAP';
$html_manage_filters_link = 'Управління поштовими фільтрами';
$html_use_graphical_smilies = 'Використовувати графічні смайлики';
$html_sent_folder_label = 'Копіювати надіслані листи у спеціальну теку:';
$html_trash_folder_label = 'Переміщати видалені листи у спеціальну теку:';
$html_colored_quotes = 'Кольорові цитати';
$html_display_struct = 'Відобразити текст структу';
$html_send_html_mail = 'Відправити лист у форматі HTML';
$html_folders = 'Папки';
$html_folders_create_failed = 'Неможливо створити паку!';
$html_folders_sub_failed = 'Не вдається підписатись до теки!';
$html_folders_unsub_failed = 'Неможливо відписатися від теки!';
$html_folders_rename_failed = 'Папку не можна перейменувати!';
$html_folders_updated = 'Папки збережені';
$html_folder_subscribe = 'Підписатися на';
$html_folder_rename = 'Перейменувати';
$html_folder_create = 'Створити нову папку з ім\'ям';
$html_folder_remove = 'Відмовитися від підписки';
$html_folder_delete = 'Видалити';
$html_folder_to = 'до';
$html_filter_remove = 'Видалити';
$html_filter_body = 'Текст повідомлення';
$html_filter_subject = 'Тема повідомлення';
$html_filter_to = 'Поле Кому';
$html_filter_cc = 'Поле "Копія"';
$html_filter_from = 'Поле Від кого';
$html_filter_change_tip = 'Щоб змінити фільтр, просто перепишіть його.';
$html_reapply_filters = 'Повторно застосувати усі фільтри';
$html_filter_contains = 'містить';
$html_filter_name = 'Назва фільтру';
$html_filter_action = 'Дія фільтра';
$html_filter_moveto = 'Перемістити до';
$html_select_one = '--Виберіть одне--';
$html_and = 'та';
$html_new_msg_in = 'Нові повідомлення в';
$html_or = 'або';
$html_move = 'Перемістити';
$html_copy = 'Копіювати';
$html_messages_to = 'вибрані повідомлення до';
$html_gotopage = 'Перейти на сторінку';
$html_gotofolder = 'Перейти в папку';
$html_other_folders = 'Список папок';
$html_page = 'Сторінка';
$html_of = 'з';
$html_view_header = 'Показати заголовок';
$html_remove_header = 'Сховати заголовок';
$html_inbox = 'Вхідні';
$html_new_msg = 'Написати';
$html_reply = 'Відповісти';
$html_reply_short = 'Попереднє:';
$html_reply_all = 'Відповісти всім';
$html_forward = 'Переслати';
$html_forward_short = 'Fwd:';
$html_forward_info = 'Переслане повідомлення буде надіслано як вкладення до цього.';
$html_delete = 'Видалити';
$html_new = 'Нове';
$html_mark = 'Видалити';
$html_att_label = 'Вкладення:';
$html_atts_label = 'Вкладення:';
$html_unknown = '[невідомо]';
$html_part_x = 'Частина %s';
$html_attach = 'Вкласти файл';
$html_attach_forget = 'Необхідно вкласти файл перед надсиланням повідомлення!';
$html_attach_delete = 'Видалити вибрані';
$html_attach_none = 'Слід вибрати файл для вкладення!';
$html_sort_by = 'Сортувати за';
$html_sort = 'Сортувати';
$html_from = 'Від';
$html_from_label = 'Від:';
$html_subject = 'Тема';
$html_subject_label = 'Тема:';
$html_date = 'Дата';
$html_date_label = 'Дата:';
$html_sent_label = 'Надіслані :';
$html_wrote = 'Написав(ла)';
$html_quote_wrote = 'На %1$s %2$s %3$s написав:';
$html_size = 'Розмір';
$html_totalsize = 'Загальний розмір';
$html_kb = 'КБ';
$html_mb = 'МБ';
$html_gb = 'ГБ';
$html_bytes = 'байт';
$html_filename = 'Назва файлу';
$html_to = 'Кому';
$html_to_label = 'Кому:';
$html_cc = 'Копія';
$html_cc_label = 'Копія:';
$html_bcc_label = 'Прихована копія:';
$html_nosubject = 'Немає теми';
$html_send = 'Надіслати';
$html_cancel = 'Скасувати';
$html_no_mail = 'Немає повідомлень.';
$html_logout = 'Вийти';
$html_msg = 'Повідомлення';
$html_msgs = 'Повідомлення';
$html_configuration = 'Даний сервер некоректно встановлений!';
$html_priority = 'Пріоритет';
$html_priority_label = 'Пріоритет:';
$html_lowest = 'Найнижчий';
$html_low = 'Низький';
$html_normal = 'Нормальний';
$html_high = 'Високий';
$html_highest = 'Найвищий';
$html_flagged = 'Відмічені';
$html_spam = 'Спам';
$html_spam_warning = 'Це повідомлення класифіковано як спам.';
$html_receipt = 'Запит на підтвердження отримання';
$html_select = 'Виділити';
$html_select_all = 'Інвертувати виділення';
$html_select_contacts = 'Виберіть контакти';
$html_loading_image = 'Завантаження зображень';
$html_send_confirmed = 'Ваша е-пошта прийнята для доставки';
$html_no_sendaction = 'Ніяких дій не зазначено. Спробуйте увімкнути JavaScript.';
$html_error_occurred = 'Виникла помилка';
$html_prefs_file_error = 'Не вдається відкрити файл налаштувань для запису.';
$html_wrap = 'Кількість символів для перенесення вихідних повідомлень:';
$html_wrap_none = 'Без перенесення';
$html_usenet_separator = 'Розділювач у стилі Usenet ("-- \n") перед підписом';
$html_mark_as = 'Позначити як';
$html_read = 'прочитане';
$html_unread = 'непрочитане';
$html_encoding_label = 'Кодування (символів):';
$html_add = 'Додати';
$html_contacts = 'Контакти %1$s';
$html_modify = 'Змінити';
$html_back = 'Назад';
$html_contact_add = 'Додати контакт';
$html_contact_mod = 'Змінити контакт';
$html_contact_first = 'Ім\'я';
$html_contact_last = 'Фамілія';
$html_contact_nick = 'Псевдонім';
$html_contact_mail = 'Електронна пошта';
$html_contact_list = 'Список контактів %1$s';
$html_contact_del = 'зі списку контактів';
$html_contact_count = '%1$d контактів';
$html_contact_err1 = 'Максимальна кількість контактів - "% 1 $ D"';
$html_contact_err2 = 'Неможливо додати новий контакт';
$html_contact_err3 = 'Ви не маєте прав доступу до списку контактів';
$html_contact_none = 'Жодних контактів не знайдено.';
$html_del_msg = 'Видалити вибрані повідомлення?';
$html_down_mail = 'Завантажити';
$original_msg = '-- Оригінальне повідомлення --';
$to_empty = 'Поле „Кому“не повинне бути пустим!';
$html_images_warning = 'Для вашої безпеки віддаленої фотографії не відображаються.';
$html_images_display = 'Відображати картинки';
$html_smtp_error_no_conn = 'Неможливо встановити SMTP з\'єднання';
$html_smtp_error_unexpected = 'Несподівана відповідь SMTP:';
$lang_could_not_connect = 'Не вдалося під\'єднатися до сервера';
$lang_invalid_msg_num = 'Поганий номер повідомлення';
$html_file_upload_attack = 'Можлива атака через завантаження файлу';
$html_invalid_email_address = 'Некоректний адрес е-пошти';
$html_invalid_msg_per_page = 'Невірна кількість повідомлень на сторінці';
$html_invalid_wrap_msg = 'Невірна ширина рядка повідомлення';
$html_seperate_msg_win = 'Повідомлення в окремому вікні';
$html_err_file_contacts = 'Не вдалося відкрити файл контактів для запису.';
$html_session_file_error = 'Не вдалося відкрити файл сеансу для запису.';
$html_login_not_allowed = 'Це ім\'я користувача не можна використовувати для з\'єднання.';
$lang_err_send_delay = 'Ви повинні чекати між двома повідомленнями електронної пошти (%1$d секунд)';
$html_search = 'Пошук';
$html_new_session = 'Наступна сесія';
$html_fd_filename = 'Завантажити %1$s';
$html_fd_mailcount = 'У теці {{PLURAL:$1|0=нема листів|1=знаходиться %1$d лист|знаходиться %1$d листів|знаходиться %1$d листи}}.';
$html_fd_mailskip = 'Такі листи не будуть частиною файлу mbox, бо вони будуть перевищувати змінну php memory_limit:';
$html_fd_filesize = 'розмір %1$d';
$html_fd_skipcount = 'з %1$d листами';
$html_fd_largefolder = 'Залежно від швидкості завантаження воно може не вдатися через перевищення часу очікування сценарію.<br />Будь ласка, перевірте повноту вашого завантаження або виберіть  вище значення змінної max_execution_time у php.ini.';
$reset_clicked = 'Ви дійсно хочете вилучити цю форму?';
$html_send_recover = 'Увійдіть, щоб відновити втрачену чернетку!';
$html_send_discard = 'Натисніть тут, щоб відхилити збережену чернетку.';

==> nocc-1.9.6.txz: usr/local/www/nocc/lang/uk.php <==
<?php
/**
 * Language configuration file for NOCC
 *
 * Copyright 2001 Nicolas Chalanset <nicocha@free.fr>
 * Copyright 2001 Olivier Cahagne <cahagn_o@epita.fr>
 *
 * This file is part of NOCC. NOCC is free software under the terms of the
 * GNU General Public License. You should have received a copy of the license
 * along with NOCC.  If not, see <http://www.gnu.org/licenses/>.
 *
 * @package    NOCC
 * @subpackage Translations
 * @license    http://www.gnu.org/licenses/ GNU General Public License
 * @version    SVN: $Id: uk.php 2660 2016-01-27 09:35:17Z siebrand $
 */
/** Ukrainian (українська)
 * 
 * See the qqq 'language' for message documentation incl. usage of parameters
 * To improve a translation please visit http://translatewiki.net
 *
 * @ingroup Language
 * @file
 *
 * @author Andriykopanytsia
 * @author Base
 * @author KEL
 * @author Prima klasy4na
 * @author Тест
 */

$lang_locale = 'uk_UA.UTF-8';
$lang_dir = 'ltr';
$default_date_format = '%d.%m.%Y';
$no_locale_date_format = '%d.%m.%Y';
$default_time_format = '%H:%M';
$err_user_empty = 'Не введений логін';
$err_passwd_empty = 'Не введений пароль';
$alt_delete = 'Видалити вибрані повідомлення';
$alt_delete_one = 'Видалити повідомлення';
$alt_new_msg = 'Нові повідомлення';
$alt_reply = 'Відповісти автору';
$alt_reply_all = 'Відповісти всім';
$alt_forward = 'Вперед';
$alt_next = 'Наступний';
$alt_prev = 'Назад';
$title_next_page = 'Наступна сторінка';
$title_prev_page = 'Попередня сторінка';
$title_next_msg = 'Наступне повідомлення';
$title_prev_msg = 'Попереднє повідомлення';
$html_theme_label = 'Тема:';
$html_welcome = 'Ласкаво просимо до %1$s';
$html_login = 'Увійти';
$html_user_label = 'Користувач:';
$html_passwd_label = 'Пароль:';
$html_submit = 'Надіслати';
$html_help = 'Довідка';
$html_server_label = 'Сервер:';
$html_wrong = 'Логін або пароль невірний';
$html_retry = 'Повторити';
$html_remember = 'Запам\'ятати налаштування';
$html_lang_label = 'Мова:';
$html_msgperpage_label = 'Повідомлень на сторінці:';
$html_preferences = 'Налаштування';
$html_full_name_label = 'Повне ім\'я:';
$html_email_address_label = 'Адреса електронної пошти';
$html_bccself = 'Копію собі';
$html_hide_addresses = 'Приховати адреси';
$html_outlook_quoting = 'Outlook стиль цитування';
$html_reply_to = 'Відповісти для';
$html_reply_to_label = 'Відповідь:';
$html_use_signature = 'Ставити підпис';
$html_signature = 'Підпис';
$html_signature_label = 'Підпис:';
$html_reply_leadin_label = 'Вступний блок відповіді:';
$html_prefs_updated = 'Налаштування оновлені';
$html_manage_folders_link = 'Керування теками IMAP';
$html_manage_filters_link = 'Управління поштовими фільтрами';
$html_use_graphical_smilies = 'Використовувати графічні смайлики';
$html_sent_folder_label = 'Копіювати надіслані листи у спеціальну теку:';
$html_trash_folder_label = 'Переміщати видалені листи у спеціальну теку:';
$html_colored_quotes = 'Кольорові цитати';
$html_display_struct = 'Відобразити текст структу';
$html_send_html_mail = 'Відправити лист у форматі HTML';
$html_folders = 'Папки';
$html_folders_create_failed = 'Неможливо створити паку!';
$html_folders_sub_failed = 'Не вдається підписатись до теки!';
$html_folders_unsub_failed = 'Неможливо відписатися від теки!';
$html_folders_rename_failed = 'Папку не можна перейменувати!';
$html_folders_updated = 'Папки збережені';
$html_folder_subscribe = 'Підписатися на';
$html_folder_rename = 'Перейменувати';
$html_folder_create = 'Створити нову папку з ім\'ям';
$html_folder_remove = 'Відмовитися від підписки';
$html_folder_delete = 'Видалити';
$html_folder_to = 'до';
$html_filter_remove = 'Видалити';
$html_filter_body = 'Текст повідомлення';
$html_filter_subject = 'Тема повідомлення';
$html_filter_to = 'Поле Кому';
$html_filter_cc = 'Поле "Копія"';
$html_filter_from = 'Поле Від кого';
$html_filter_change_tip = 'Щоб змінити фільтр, просто перепишіть його.';
$html_reapply_filters = 'Повторно застосувати усі фільтри';
$html_filter_contains = 'містить';
$html_filter_name = 'Назва фільтру';
$html_filter_action = 'Дія фільтра';
$html_filter_moveto = 'Перемістити до';
$html_select_one = '--Виберіть одне--';
$html_and = 'та';
$html_new_msg_in = 'Нові повідомлення в';
$html_or = 'або';
$html_move = 'Перемістити';
$html_copy = 'Копіювати';
$html_messages_to = 'вибрані повідомлення до';
$html_gotopage = 'Перейти на сторінку';
$html_gotofolder = 'Перейти в папку';
$html_other_folders = 'Список папок';
$html_page = 'Сторінка';
$html_of = 'з';
$html_view_header = 'Показати заголовок';
$html_remove_header = 'Сховати заголовок';
$html_inbox = 'Вхідні';
$html_new_msg = 'Написати';
$html_reply = 'Відповісти';
$html_reply_short = 'Попереднє:';
$html_reply_all = 'Відповісти всім';
$html_forward = 'Переслати';
$html_forward_short = 'Fwd:';
$html_forward_info = 'Переслане повідомлення буде надіслано як вкладення до цього.';
$html_delete = 'Видалити';
$html_new = 'Нове';
$html_mark = 'Видалити';
$html_att_label = 'Вкладення:';
$html_atts_label = 'Вкладення:';
$html_unknown = '[невідомо]';
$html_part_x = 'Частина %s';
$html_attach = 'Вкласти файл';
$html_attach_forget = 'Необхідно вкласти файл перед надсиланням повідомлення!';
$html_attach_delete = 'Видалити вибрані';
$html_attach_none = 'Слід вибрати файл для вкладення!';
$html_sort_by = 'Сортувати за';
$html_sort = 'Сортувати';
$html_from = 'Від';
$html_from_label = 'Від:';
$html_subject = 'Тема';
$html_subject_label = 'Тема:';
$html_date = 'Дата';
$html_date_label = 'Дата:';
$html_sent_label = 'Надіслані :';
$html_wrote = 'Написав(ла)';
$html_quote_wrote = 'На %1$s %2$s %3$s написав:';
$html_size = 'Розмір';
$html_totalsize = 'Загальний розмір';
$html_kb = 'КБ';
$html_mb = 'МБ';
$html_gb = 'ГБ';
$html_bytes = 'байт';
$html_filename = 'Назва файлу';
$html_to = 'Кому';
$html_to_label = 'Кому:';
$html_cc = 'Копія';
$html_cc_label = 'Копія:';
$html_bcc_label = 'Прихована копія:';
$html_nosubject = 'Немає теми';
$html_send = 'Надіслати';
$html_cancel = 'Скасувати';
$html_no_mail = 'Немає повідомлень.';
$html_logout = 'Вийти';
$html_msg = 'Повідомлення';
$html_msgs = 'Повідомлення';
$html_configuration = 'Даний сервер некоректно встановлений!';
$html_priority = 'Пріоритет';
$html_priority_label = 'Пріоритет:';
$html_lowest = 'Найнижчий';
$html_low = 'Низький';
$html_normal = 'Нормальний';
$html_high = 'Високий';
$html_highest = 'Найвищий';
$html_flagged = 'Відмічені';
$html_spam = 'Спам';
$html_spam_warning = 'Це повідомлення класифіковано як спам.';
$html_receipt = 'Запит на підтвердження отримання';
$html_select = 'Виділити';
$html_select_all = 'Інвертувати виділення';
$html_select_contacts = 'Виберіть контакти';
$html_loading_image = 'Завантаження зображень';
$html_send_confirmed = 'Ваша е-пошта прийнята для доставки';
$html_no_sendaction = 'Ніяких дій не зазначено. Спробуйте увімкнути JavaScript.';
$html_error_occurred = 'Виникла помилка';
$html_prefs_file_error = 'Не вдається відкрити файл налаштувань для запису.';
$html_wrap = 'Кількість символів для перенесення вихідних повідомлень:';
$html_wrap_none = 'Без перенесення';
$html_usenet_separator = 'Розділювач у стилі Usenet ("-- \n") перед підписом';
$html_mark_as = 'Позначити як';
$html_read = 'прочитане';
$html_unread = 'непрочитане';
$html_encoding_label = 'Кодування (символів):';
$html_add = 'Додати';
$html_contacts = 'Контакти %1$s';
$html_modify = 'Змінити';
$html_back = 'Назад';
$html_contact_add = 'Додати контакт';
$html_contact_mod = 'Змінити контакт';
$html_contact_first = 'Ім\'я';
$html_contact_last = 'Прізвище';
$html_contact_nick = 'Псевдонім';
$html_contact_mail = 'Електронна пошта';
$html_contact_list = 'Список контактів %1$s';
$html_contact_del = 'зі списку контактів';
$html_contact_count = '%1$d контактів';
$html_contact_err1 = 'Максимальна кількість контактів - "% 1 $ D"';
$html_contact_err2 = 'Неможливо додати новий контакт';
$html_contact_err3 = 'Ви не маєте прав доступу до списку контактів';
$html_contact_none = 'Жодних контактів не знайдено.';
$html_contact_ruler_top = 'Вгору';
$html_contact_listcheck_title = 'Позначте, щоб додати адресу електронної пошти в список.';
$html_contact_list_add = 'Додати в список';
$html_contact_listname = 'Назва списку';
$html_contact_listonly = 'Тільки списки';
$html_contact_all = 'Показати усе';
$html_contact_add_confirm = 'Додавати електронні пошти до існуючого списку?';
$html_del_msg = 'Видалити вибрані повідомлення?';
$html_down_mail = 'Завантажити';
$original_msg = '-- Оригінальне повідомлення --';
$to_empty = 'Поле „Кому“не повинне бути пустим!';
$html_images_warning = 'Для вашої безпеки віддаленої фотографії не відображаються.';
$html_images_display = 'Відображати картинки';
$html_smtp_error_no_conn = 'Неможливо встановити SMTP з\'єднання';
$html_smtp_error_unexpected = 'Несподівана відповідь SMTP:';
$lang_could_not_connect = 'Не вдалося під\'єднатися до сервера';
$lang_invalid_msg_num = 'Поганий номер повідомлення';
$html_file_upload_attack = 'Можлива атака через завантаження файлу';
$html_invalid_email_address = 'Некоректний адрес е-пошти';
$html_invalid_msg_per_page = 'Невірна кількість повідомлень на сторінці';
$html_invalid_wrap_msg = 'Невірна ширина рядка повідомлення';
$html_seperate_msg_win = 'Повідомлення в окремому вікні';
$html_err_file_contacts = 'Не вдалося відкрити файл контактів для запису.';
$html_session_file_error = 'Не вдалося відкрити файл сеансу для запису.';
$html_login_not_allowed = 'Це ім\'я користувача не можна використовувати для з\'єднання.';
$lang_err_send_delay = 'Ви повинні чекати між двома повідомленнями електронної пошти (%1$d секунд)';
$html_search = 'Пошук';
$html_new_session = 'Наступна сесія';
$html_fd_filename = 'Завантажити %1$s';
$html_fd_mailcount = 'У теці {{PLURAL:$1|0=нема листів|1=знаходиться %1$d лист|знаходиться %1$d листів|знаходиться %1$d листи}}.';
$html_fd_mailskip = 'Такі листи не будуть частиною файлу mbox, бо вони будуть перевищувати змінну php memory_limit:';
$html_fd_filesize = 'розмір %1$d';
$html_fd_skipcount = 'з %1$d листами';
$html_fd_largefolder = 'Залежно від швидкості завантаження воно може не вдатися через перевищення часу очікування сценарію.<br />Будь ласка, перевірте повноту вашого завантаження або виберіть  вище значення змінної max_execution_time у php.ini.';
$reset_clicked = 'Ви дійсно хочете вилучити цю форму?';
$html_send_recover = 'Увійдіть, щоб відновити втрачену чернетку!';
$html_send_discard = 'Натисніть тут, щоб відхилити збережену чернетку.';
$html_collect_label = 'Автоматичний збір адрес електронної пошти:';
$html_collect_option0 = 'Ніколи';
$html_collect_option1 = 'Тільки з вихідних листів';
$html_collect_option2 = 'Тільки з відкритих листів';
$html_collect_option3 = 'Завжди';
